<?php
/**
 * Plugin Name: Dadevarzan WordPress course plugin
 * Plugin URI: https://wordpress.org/plugins/dadevarzan-wp-course
 * GitHub Plugin URI: https://github.com/dadevarzan/dadevarzan-wp-course
 * Description: course post type for wordpress
 * Version: 1.1.9
 * Author: Dadevarzan Team
 * Author URI: http://www.dadevarzan.com
 * Text Domain: dadevarzan-wp-course
 * Domain Path: /languages
*/

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
    die;
}

if ( !class_exists( 'dadevarzanWpCourse' ) ) {

    class dadevarzanWpCourse
    {

        public static function initialize()
        {
            add_action( 'plugins_loaded', 'dadevarzanWpCourse::load_text_domain' );
            add_action( 'init', 'dadevarzanWpCourse::add_post_type' );
            add_action( 'init', 'dadevarzanWpCourse::add_fields' );
            add_action('init', 'dadevarzanWpCourse::add_taxonomy');
            add_action('init', 'dadevarzanWpCourse::add_role_caps');
            add_action( 'plugins_loaded', 'dadevarzanWpCourse::load_templates' );

        }

        public static function add_post_type()
        {

            $labels = array(
                "name" => __('Courses', 'dadevarzan-wp-course'),
                "singular_name" => __('Course', 'dadevarzan-wp-course'),
                "all_items" => __('All Courses', 'dadevarzan-wp-course'),
                "add_new" => __('Add Course', 'dadevarzan-wp-course'),
                "add_new_item" => __('Add New Course', 'dadevarzan-wp-course'),
                "edit_item" => __('Edit Course', 'dadevarzan-wp-course'),
                "new_item" => __('New Course', 'dadevarzan-wp-course'),
                "view_item" => __('View Course', 'dadevarzan-wp-course'),
            );

            $args = array(
                "label" => __('Courses', 'dadevarzan-wp-course'),
                "labels" => $labels,
                "description" => "",
                "public" => true,
                "publicly_queryable" => true,
                "show_ui" => true,
                "show_in_rest" => true,
                "rest_base" => "",
				"show_in_nav_menus" => true,
                "has_archive" => true,
                "show_in_menu" => true,
                "exclude_from_search" => false,
                "hierarchical" => false,
                "rewrite" => array( "slug" => "course", "with_front" => true ),
                "query_var" => true,
                "menu_icon" => "dashicons-welcome-learn-more",
                "supports" => array( "title", "excerpt", "editor", "thumbnail", "comments", "author" ),
                "capability_type" => array('course', 'courses'),
                "map_meta_cap" => true,
                "taxonomies" => array("course_category"),
            );

            register_post_type( "course", $args );

        }

        public static function add_fields()
        {

            if( function_exists('acf_add_local_field_group') ):

                acf_add_local_field_group(array(
                    'key' => 'group_5a0be039b74bc',
                    'title' => __('Courses', 'dadevarzan-wp-course'),
                    'fields' => array(
                        array(
                            'key' => 'field_5a0be06fbb48c',
                            'label' => __('Syllabuses', 'dadevarzan-wp-course'),
                            'name' => 'crs_curriculum',
                            'type' => 'repeater',
                            'instructions' => '',
                            'required' => 0,
                            'conditional_logic' => 0,
                            'wrapper' => array(
                                'width' => '',
                                'class' => '',
                                'id' => '',
                            ),
                            'collapsed' => 'field_5a0be47cbb48d',
                            'min' => 0,
                            'max' => 0,
                            'layout' => 'table',
                            'button_label' => __('New Syllabus', 'dadevarzan-wp-course'),
                            'sub_fields' => array(
                                array(
                                    'key' => 'field_5a0be47cbb48d',
                                    'label' => __('Title', 'dadevarzan-wp-course'),
                                    'name' => 'crs_curriculum_title',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                            ),
                        ),
                        array(
                            'key' => 'field_5a0be4e3bb48e',
                            'label' => __('Start date', 'dadevarzan-wp-course'),
                            'name' => 'crs_start_date',
                            'type' => 'text',
                            'instructions' => '',
                            'required' => 0,
                            'conditional_logic' => 0,
                            'wrapper' => array(
                                'width' => '',
                                'class' => '',
                                'id' => '',
                            ),
                            'default_value' => '',
                            'placeholder' => '',
                            'prepend' => '',
                            'append' => '',
                            'maxlength' => '',
                        ),
                        array(
                            'key' => 'field_5a0be558bb48f',
                            'label' => __('Duration', 'dadevarzan-wp-course'),
                            'name' => 'crs_duration',
                            'type' => 'text',
                            'instructions' => '',
                            'required' => 0,
                            'conditional_logic' => 0,
                            'wrapper' => array(
                                'width' => '',
                                'class' => '',
                                'id' => '',
                            ),
                            'default_value' => '',
                            'placeholder' => '',
                            'prepend' => '',
                            'append' => '',
                            'maxlength' => '',
                        ),
                        array(
                            'key' => 'field_5a0be59cbb490',
                            'label' => __('Certificate title', 'dadevarzan-wp-course'),
                            'name' => 'crs_certificate_title',
                            'type' => 'text',
                            'instructions' => '',
                            'required' => 0,
                            'conditional_logic' => 0,
                            'wrapper' => array(
                                'width' => '',
                                'class' => '',
                                'id' => '',
                            ),
                            'default_value' => '',
                            'placeholder' => '',
                            'prepend' => '',
                            'append' => '',
                            'maxlength' => '',
                        ),
                        array(
                            'key' => 'field_5a0be5c8bb491',
                            'label' => __('Certificate image', 'dadevarzan-wp-course'),
                            'name' => 'crs_certificate_image',
                            'type' => 'image',
                            'instructions' => '',
                            'required' => 0,
                            'conditional_logic' => 0,
                            'wrapper' => array(
                                'width' => '',
                                'class' => '',
                                'id' => '',
                            ),
                            'return_format' => 'url',
                            'preview_size' => 'thumbnail',
                            'library' => 'all',
                            'min_width' => '',
                            'min_height' => '',
                            'min_size' => '',
                            'max_width' => '',
                            'max_height' => '',
                            'max_size' => '',
                            'mime_types' => 'jpeg,jpg,gif,png',
                        ),
                        array(
                            'key' => 'field_5a0be63bbb492',
                            'label' => __('Instructor name', 'dadevarzan-wp-course'),
                            'name' => 'crs_instructor_name',
                            'type' => 'text',
                            'instructions' => '',
                            'required' => 0,
                            'conditional_logic' => 0,
                            'wrapper' => array(
                                'width' => '',
                                'class' => '',
                                'id' => '',
                            ),
                            'default_value' => '',
                            'placeholder' => '',
                            'prepend' => '',
                            'append' => '',
                            'maxlength' => '',
                        ),
                        array(
                            'key' => 'field_5a0be6cdbb493',
                            'label' => __('Instructor image', 'dadevarzan-wp-course'),
                            'name' => 'crs_instructor_image',
                            'type' => 'image',
                            'instructions' => '',
                            'required' => 0,
                            'conditional_logic' => 0,
                            'wrapper' => array(
                                'width' => '',
                                'class' => '',
                                'id' => '',
                            ),
                            'return_format' => 'url',
                            'preview_size' => 'thumbnail',
                            'library' => 'all',
                            'min_width' => 100,
                            'min_height' => 100,
                            'min_size' => '',
                            'max_width' => 500,
                            'max_height' => 500,
                            'max_size' => '',
                            'mime_types' => 'jpg,jpeg,png,gif',
                        ),
                        array(
                            'key' => 'field_5a0be704bb494',
                            'label' => __('Instructor info', 'dadevarzan-wp-course'),
                            'name' => 'crs_instructor_desc',
                            'type' => 'wysiwyg',
                            'instructions' => '',
                            'required' => 0,
                            'conditional_logic' => 0,
                            'wrapper' => array(
                                'width' => '',
                                'class' => '',
                                'id' => '',
                            ),
                            'default_value' => '',
                            'tabs' => 'visual',
                            'toolbar' => 'full',
                            'media_upload' => 1,
                            'delay' => 0,
                        ),
                        array(
                            'key' => 'field_5a0be75dbb495',
                            'label' => __('Instructor URL', 'dadevarzan-wp-course'),
                            'name' => 'crs_instructor_url',
                            'type' => 'url',
                            'instructions' => '',
                            'required' => 0,
                            'conditional_logic' => 0,
                            'wrapper' => array(
                                'width' => '',
                                'class' => '',
                                'id' => '',
                            ),
                            'default_value' => '',
                            'placeholder' => '',
                        ),
                    ),
                    'location' => array(
                        array(
                            array(
                                'param' => 'post_type',
                                'operator' => '==',
                                'value' => 'course',
                            ),
                        ),
                    ),
                    'menu_order' => 0,
                    'position' => 'acf_after_title',
                    'style' => 'default',
                    'label_placement' => 'top',
                    'instruction_placement' => 'label',
                    'hide_on_screen' => '',
                    'active' => 1,
                    'description' => '',
                ));

            endif;

        }

        public static function add_taxonomy()
        {

            $labels = array(
                "name" => __('Course Categories', 'dadevarzan-wp-course'),
                "singular_name" => __('Course Category', 'dadevarzan-wp-course'),
            );

            $args = array(
                "label" => __('Course Categories', 'dadevarzan-wp-course'),
                "labels" => $labels,
                "public" => true,
                "hierarchical" => true,
                "show_ui" => true,
                "show_in_menu" => true,
                "show_in_nav_menus" => true,
                "query_var" => true,
                "rewrite" => array('slug' => 'course_category', 'with_front' => true,),
                "show_admin_column" => true,
                "show_in_rest" => true,
                "rest_base" => "",
                "show_in_quick_edit" => true,
                'capabilities' => array(
                    'manage_terms' => 'manage_categories',
                    'edit_terms' => 'manage_categories',
                    'delete_terms' => 'manage_categories',
                    'assign_term' => 'manage_categories',
                    'assign_terms' => 'manage_categories',
                ),
            );

            register_taxonomy('course_category', array('course'), $args);

        }

        public static function add_role_caps()
        {

            // Add the roles you'd like to administer the custom post types
            $roles = array('wpseo_editor', 'wpseo_manager', 'shop_manager', 'editor', 'administrator');

            // Loop through each role and assign capabilities
            foreach($roles as $the_role) {

                $role = get_role($the_role);

                if ( empty($role) ) {
                    continue;
                }

                $role->add_cap( 'read' );
                $role->add_cap( 'read_course' );
                $role->add_cap( 'edit_course' );
                $role->add_cap( 'edit_courses' );
                $role->add_cap( 'edit_private_courses' );
                $role->add_cap( 'edit_published_courses' );
                $role->add_cap( 'edit_others_courses' );
                $role->add_cap( 'delete_course' );
                $role->add_cap( 'delete_courses' );
                $role->add_cap( 'delete_private_courses' );
                $role->add_cap( 'delete_published_courses' );
                $role->add_cap( 'delete_others_courses' );
                $role->add_cap( 'publish_courses' );
                $role->add_cap( 'read_private_courses' );

            }

        }

        public static function load_templates() {

            /**
             * Return if the builder isn't installed or if the current
             * version doesn't support registering templates.
             */
            if ( ! class_exists( 'FLBuilder' ) || ! method_exists( 'FLBuilder', 'register_templates' ) ) {
                return;
            }

            $layoutTemplatePath = plugin_dir_path( __FILE__ ) . 'data/templates.dat';
            if ( file_exists( $layoutTemplatePath ) && class_exists( 'FLThemeBuilder' ) ) {
                FLBuilder::register_templates( $layoutTemplatePath, array('group' => 'course'));
            }

        }

        public static function load_text_domain()
        {
            load_plugin_textdomain( 'dadevarzan-wp-course' , FALSE, basename( dirname( __FILE__ ) ) . '/languages'  );
        }

    }

    dadevarzanWpCourse::initialize();

}
